#!/bin/sh -x
# build script for oss_4.2 (git)
# built on tc-5.x

set -o nounset
set -o errexit

. /etc/init.d/tc-functions

###################################################################################################
###################################################################################################
# Downloads available

# git clone http://git.code.sf.net/p/opensound/git

# http://www.4front-tech.com/developer/sources/stable/gpl/

###################################################################################################

# Build oss v4.2 (git source)

name='oss'
srcpath='/usr/src/'
srcdir='oss_git'
builddir='oss_build'
ver='4.2'
pkg=/tmp/${name}_build/pkg
doc=/tmp/${name}_build/doc
pkgdir=/tmp/${name}_build
src=/usr/$srcdir


##############################################
## load deps

tceinstalled="/usr/local/tce.installed"
optional_path="/etc/sysconfig/tcedir/optional"
cd $optional_path
tce_path=`realpath ${PWD} | sed -e 's/\/optional//'`

deps="compiletc.tcz \
automake.tcz \
findutils.tcz \
git.tcz \
gtk3-dev.tcz \
linux-3.8.10-sources-env.tcz \
gawk.tcz \
glibc_base-dev.tcz \
squashfs-tools-4.x.tcz"


for i in `echo $deps`; do 

pkgname=`basename "$i" .tcz`

# check if tcz installed already
if [ -f ${tceinstalled}/"$pkgname" ]; then
	echo "${WHITE}"$i" ${GREEN}Already loaded${NORMAL}"

else
	if  [ ! -f ${tceinstalled}/"$pkgname" ]; then

# tcz not installed, then install from local path
	if [ -f ${tce_path}/optional/"$i" ]; then
	  while [ ! -f ${tceinstalled}/"$pkgname" ]; do
	    tce-load -i "$pkgname"; sleep 1
	  done
		if [ -f ${tceinstalled}/"$pkgname" ]; then
			echo "${CYAN}"$i" ${BLUE}loaded locally${NORMAL}"
		fi

# tcz not downloaded, install from repo
	elif [ ! -f ${tce_path}/optional/"$i" ]; then
	    tce-load -wil "$pkgname"; sleep 1
		if [ -f ${tceinstalled}/"$pkgname" ]; then
			echo "${MAGENTA}"$i" ${YELLOW}downloaded from repo${NORMAL}"
		fi
	fi
	fi
fi

if [ ! -f "${tceinstalled}/$pkgname" ]; then
	echo "${RED}$i failed to load, exiting..${NORMAL}"; sleep 3; exit 5
fi

done


##############################################
# sudo /sbin/ldconfig -v && sleep 2


##############################################
#cleanup
echo -e "\n\n Cleaning up previous builds, start fresh... "
[ -d "${srcpath}$srcdir" ] && find /usr -name src -exec rm -rf {} \; >/dev/null 2>&1
[ -d "${srcpath}$srcdir" ] && find /usr -type d -print0 | xargs -0 -r sudo rm -rvf



##############################################
# prep kernel sources

cliorx linux-3.8.10-sources-env.sh

##############################################
# pkg sources

if [ -d "${srcpath}$srcdir" ]; then
	echo -e "\n\n Previous build directory found, discard before continuing... "
	sleep 10
	exit 1
fi


echo -e "\n\n Unpacking src... "
#sudo mkdir -p /usr/src

sudo find / -name "${name}*.tar.gz" -type f -exec sh -c exec cp -f "$@" /tmp X {} +

if [ ! -f /tmp/${name}*.tar.gz ]; then
	echo -e "\n\n ${name}*.tar.bz2 not found, downloading from git source...\n\n"
	cd /usr/src
	sudo git clone http://git.code.sf.net/p/opensound/git $srcdir
else 
	tar zxf ${name}*.tar.gz -C /usr/src
fi

echo -e "\n\n Setting file ownership..."
[ -d $srcdir ] && sudo chown tc.staff -R $srcdir



echo -e "\n\n Export compiler flags... "
export CFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export CXXFLAGS="-march=i486 -mtune=i686 -Os -pipe"

mkdir -p /tmp/$builddir
cd /tmp/${builddir}

echo -e "\n Ok moving right along...\n\n Runing configure..."
${srcpath}${srcdir}/configure


echo -e "\n\n Running make install..."
sudo make install

echo -e "\n Done"
echo -e "\n Modules can be found in /lib/modules/3.8.10-tinycore/kernel/OSS"
sleep 20
exit 2
